@@ -10,10 +10,7 @@ class Flask():
     def __init__(self, app):
         self.app = app
         self.route = '/nodecdn.js'
-
-        @app.route(self.route)
-        def nodecdnpath():
-            return "Works!"
+        return self
         
     def change_path(self, path):
         self.route = path
\ No newline at end of file
